import arrow_right from "@/assets/vector1.svg";
import { useSwiper } from "swiper/react";
import { useState } from "react";
import Image from "next/image";
import Link from "next/link";

export default function FundTypeSlide({ data }) {
  const swiper = useSwiper();
  const [isBeginning, setIsBeggining] = useState(false);
  const [isEnd, setIsEnd] = useState(false);
  const items = new Array(3).fill(null);
  const fallbackImage =
    "https://res.cloudinary.com/dnfktmgnt/image/upload/v1721282111/knuuiqpucpkbeianpghn.jpg";

  // Function to generate the dynamic URL based on the slide title
  const generateUrl = (slideTitle) => {
    switch (slideTitle.toLowerCase()) {
      case "property types":
        return "/property";
      case "car types":
        return "/car";
      case "jewellery types":
        return "/jewelry";
      default:
        return "/";
    }
  };

  return (
    <div className="flex flex-row gap-4 my-10 py-3 px-1">
      <div className="flex flex-col pt-5 items-start">
        <div className="flex font-medium text-[#010101] text-xl">
          Explore by
        </div>
        <div className="flex text-4xl font-semibold text-[#002D4F] mt-2">
          {data.slide_title}
        </div>
        <div className="flex flex-row gap-2 my-5">
          <div className="rounded-2xl bg-[#002D4F] w-[31.8px] h-[5.6px]" />
          <div className="rounded-lg bg-[#8D7C3B] w-[84.9px] h-[5.6px]" />
        </div>
        <div className="text-lg text-left leading-[30px] text-black inline-block w-[350px]">
          {data.slide_description}
        </div>
        <div className="flex flex-row mt-5 space-x-8">
          <div onClick={() => swiper.slidePrev()} className="cursor-pointer">
            <div className="btn-gradient px-2 py-1 rounded">
              <Image
                src={arrow_right}
                alt="previous"
                className="transform rotate-180"
              />
            </div>
          </div>
          <div onClick={() => swiper.slideNext()} className="cursor-pointer">
            <div className="btn-gradient px-2 py-1 rounded">
              <Image src={arrow_right} alt="next" />
            </div>
          </div>
        </div>
      </div>
      <div className="grid grid-cols-3 gap-x-8">
        {items.map((_, index) => (
          <div
            key={index}
            className="shadow-[0px_0px_8px_rgba(0,_0,_0,_0.15)] rounded-md bg-white col-span-1"
          >
            <div className="flex w-full h-[170px]">
              <Image
                width={350}
                height={350}
                className="rounded-md object-cover"
                alt="photo"
                src={
                  data.photos && data.photos[index]
                    ? data.photos[index]
                    : fallbackImage
                }
              />
            </div>
            <div className="px-2">
              <div className="text-[#002D4F] mt-4 mb-2 text-center text-xl font-medium w-full inline-block">
                {data.context_types[index]}
              </div>
              <div className="text-xs leading-[22px] w-full text-center text-black inline-block px-3">
                Lorem ipsum placeholder or dummy text used in typesetting and
                graphic design for previewing layouts.
              </div>
              <Link href={generateUrl(data.slide_title)}>
                <span className="text-sm my-3 cursor-pointer text-[#002D4F] [text-decoration:underline] font-medium inline-block w-full text-center">
                  View All
                </span>
              </Link>
            </div>
          </div>
        ))}
      </div>
    </div>
  );
}
